package sun.misc;

import java.security.CodeSigner;
import java.security.cert.Certificate;
import java.util.jar.Manifest;
import sun.nio.ByteBuffered;
import java.nio.ByteBuffer;
import java.io.EOFException;
import java.util.Arrays;
import java.io.InterruptedIOException;
import java.io.IOException;
import java.net.URL;
import java.io.InputStream;

public abstract class Resource
{
    private InputStream cis;
    
    public Resource() {
    }
    
    public abstract String getName();
    
    public abstract URL getURL();
    
    public abstract URL getCodeSourceURL();
    
    public abstract InputStream getInputStream() throws IOException;
    
    public abstract int getContentLength() throws IOException;
    
    private synchronized InputStream cachedInputStream() throws IOException {
        if (this.cis == null) {
            this.cis = this.getInputStream();
        }
        return this.cis;
    }
    
    public byte[] getBytes() throws IOException {
        InputStream cachedInputStream = this.cachedInputStream();
        int interrupted = Thread.interrupted();
        int contentLength;
        Label_0009: {
            try {
                contentLength = this.getContentLength();
            }
            catch (InterruptedIOException ex) {
                Thread.interrupted();
                interrupted = 1;
                continue;
            }
        }
        byte[] original;
        try {
            original = new byte[0];
            if (contentLength == -1) {
                contentLength = Integer.MAX_VALUE;
            }
            int i = 0;
            while (i < contentLength) {
                int min;
                if (i >= original.length) {
                    min = Math.min(contentLength - i, original.length + 1024);
                    if (original.length < i + min) {
                        original = Arrays.copyOf(original, i + min);
                    }
                }
                else {
                    min = original.length - i;
                }
                int read = 0;
                try {
                    read = cachedInputStream.read(original, i, min);
                }
                catch (InterruptedIOException ex2) {
                    Thread.interrupted();
                    interrupted = 1;
                }
                if (read < 0) {
                    if (contentLength != Integer.MAX_VALUE) {
                        throw new EOFException("Detect premature EOF");
                    }
                    if (original.length != i) {
                        original = Arrays.copyOf(original, i);
                        break;
                    }
                    break;
                }
                else {
                    i += read;
                }
            }
        }
        finally {
            try {
                cachedInputStream.close();
            }
            catch (InterruptedIOException ex3) {
                interrupted = 1;
            }
            catch (IOException ex4) {}
            if (interrupted != 0) {
                Thread.currentThread().interrupt();
            }
        }
        return original;
    }
    
    public ByteBuffer getByteBuffer() throws IOException {
        InputStream cachedInputStream = this.cachedInputStream();
        if ((cachedInputStream instanceof ByteBuffered)) {
            return ((ByteBuffered)cachedInputStream).getByteBuffer();
        }
        return null;
    }
    
    public Manifest getManifest() throws IOException {
        return null;
    }
    
    public Certificate[] getCertificates() {
        return null;
    }
    
    public CodeSigner[] getCodeSigners() {
        return null;
    }
}
